@@ -1,4 +1,5 @@
 import os
+import sys
 
 import click
 import web3
@@ -10,7 +11,9 @@ CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 _NODE_URL = os.environ.get('NODEURL', 'http://localhost:8545')
 _TOKEN = Web3.toChecksumAddress(os.environ.get('NFT',
-       os.environ.get('TOKEN', '0x3d7Eec9C41c7A99489fD17e6B087f9C827b16d3F')))
+                                               os.environ.get('TOKEN',
+                                                              '0x3d7Eec9C41c7A99489fD17e6B087f9C827b16d3F')))
+PRIVATE_KEY = os.environ.get('PRIVATE_KEY')
 POA_NETS = {97, 56, 4}
 ABI_712 = [
     {
@@ -51,7 +54,7 @@ to_hex = lambda src: '0x' + (''.join('%02x' % x for x in src))
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
-@click.version_option(version='1.0.1')
+@click.version_option(version='1.0.2')
 def mininft():
     pass
 
@@ -60,13 +63,19 @@ def mininft():
 @click.argument('destination')
 @click.argument('tokenid')
 @click.option('--token', default=_TOKEN, help='Nft token address')
-@click.option('--private_key', help='User account private key')
+@click.option('--private_key', default=PRIVATE_KEY,
+              help='User account private key')
 @click.option('--node_url', default=_NODE_URL,
               help='Node url (defaults to env.var NODE_URL)')
 @click.option('--poa', is_flag=True, help='force use POA network middleware')
 def send(destination, tokenid, token, private_key, node_url, poa):
     click.echo("Node: %r" % node_url)
     click.echo("Token: %r" % token)
+
+    if private_key is None:
+        print('Private key is required. Please specify in arguments or env.',
+              file=sys.stderr)
+        exit(-1)
     click.echo("Private key: %r" % (Hide(private_key)))
 
     if not poa:
@@ -93,6 +102,7 @@ def send(destination, tokenid, token, private_key, node_url, poa):
     except web3.exceptions.ContractLogicError as error:
         click.echo("can't send token. No Tx")
         click.echo("error msg: %s" % error.args[0])
+        exit(-1)
 
 
 if __name__ == '__main__':
